==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Notiek migrācija. Lūdzu, pagaidiet, līdz migrēšana ir pabeigta",
    "Migration started …" : "Uzsākta migrācija...",
    "Saved" : "Saglabāts",
    "Not saved" : "Nav saglabāts",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "Local" : "Lokāls",
    "Private" : "Privāts",
    "Only visible to local users" : "Redzami tikai lokālajiem lietotājiem",
    "Only visible to you" : "Redzams tikai jums",
    "Contacts" : "Kontakti",
    "Visible to local users and to trusted servers" : "Redzama uz vietējiem lietotājiem un uzticamiem serveriem",
    "Public" : "Publisks",
    "Will be synced to a global and public address book" : "Tiks sinhronizēts ar globālu un publisku adrešu grāmatu",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Couldn't remove app." : "Nebija iespējams noņemt lietotni.",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "lietotņu instalēšana un atjaunināšana, izmantojot lietotņu veikalu vai Federatīvo Cloud koplietošanu",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Unlimited" : "Neierobežota",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "by" : "līdz",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "User documentation" : "Lietotāja dokumentācija",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Enable" : "Aktivēt",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Cancel" : "Atcelt",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Group admin for" : "Admin grupa",
    "Quota" : "Apjoms",
    "Language" : "Valoda",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Default quota" : "Apjoms pēc noklusējuma",
    "All languages" : "Visas valodas",
    "Updates" : "Atjauninājumi",
    "Admins" : "Admins",
    "Everyone" : "Visi",
    "Add group" : "Pievienot grupu",
    "Never" : "Nekad",
    "App update" : "Programmu atjaunināšana",
    "SSL Root Certificates" : "SSL Root Sertifikāti",
    "Common Name" : "Kopīgais nosaukums",
    "Valid until" : "Derīgs līdz",
    "Issued By" : "Izsniedza",
    "Valid until %s" : "Derīgs līdz %s",
    "Import root certificate" : "Importēt root sertifikātu",
    "Administrator documentation" : "Administratora dokumentācija",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "None" : "Nav",
    "Login" : "Autorizēties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-pasta serveris",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "mail" : "e-pasts",
    "Authentication method" : "Autentifikācijas metode",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Send email" : "Sūtīt e-pastu",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Version" : "Versija",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Please read carefully before activating server-side encryption: " : "Lūdzu, izlasiet uzmanīgi pirms aktivējiet servera šifrēšanu:",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Start migration" : "Sākt migrāciju",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Sharing" : "Koplietošana",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Allow users to share via link" : "Ļaut lietotājiem koplietot caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Personal" : "Personīgs",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Select from Files" : "Izvēlēties no Datnes",
    "Remove image" : "Novākt attēlu",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Choose as profile picture" : "Izvēlēties kā profila attēlu",
    "Details" : "Detaļas",
    "Full name" : "Pilns vārds",
    "No display name set" : "Nav norādīts ekrāna vārds",
    "Your email address" : "Jūsu e-pasta adrese",
    "No email address set" : "Nav norādīts e-pasts",
    "Phone number" : "Tālruņa numurs",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Address" : "Adrese",
    "Your postal address" : "Jūsu pasta adrese",
    "Website" : "Mājaslapa",
    "Twitter" : "Twitter",
    "Help translate" : "Palīdzi tulkot",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Disconnect" : "Atvienot",
    "Not supported!" : "Nav atbalstīts!",
    "Press ⌘-C to copy." : "Spied ⌘-C lai kopētu.",
    "Press Ctrl-C to copy." : "Spied Ctrl-C lai kopētu.",
    "Store credentials" : "Saglabāt akreditācijas datus",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Share" : "Koplietot"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Notiek migrācija. Lūdzu, pagaidiet, līdz migrēšana ir pabeigta",
    "Migration started …" : "Uzsākta migrācija...",
    "Saved" : "Saglabāts",
    "Not saved" : "Nav saglabāts",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Valid until {date}" : "Valīds līdz {date}",
    "Delete" : "Dzēst",
    "Local" : "Lokāls",
    "Private" : "Privāts",
    "Only visible to local users" : "Redzami tikai lokālajiem lietotājiem",
    "Only visible to you" : "Redzams tikai jums",
    "Contacts" : "Kontakti",
    "Visible to local users and to trusted servers" : "Redzama uz vietējiem lietotājiem un uzticamiem serveriem",
    "Public" : "Publisks",
    "Will be synced to a global and public address book" : "Tiks sinhronizēts ar globālu un publisku adrešu grāmatu",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Select a profile picture" : "Izvēlieties profila attēlu",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Couldn't remove app." : "Nebija iespējams noņemt lietotni.",
    "Couldn't update app." : "Nevarēja atjaunināt lietotni.",
    "Wrong password" : "Nepareiza parole",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "lietotņu instalēšana un atjaunināšana, izmantojot lietotņu veikalu vai Federatīvo Cloud koplietošanu",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "You need to set your user email before being able to send test emails." : "Nepieciešams norādīt sava lietotāja e-pasta adresi, lai nosūtīta testa e-pastus.",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Additional settings" : "Papildu iestatījumi",
    "Sharing" : "Koplietošana",
    "Personal info" : "Personiskā informācija",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Unlimited" : "Neierobežota",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "by" : "līdz",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "User documentation" : "Lietotāja dokumentācija",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Enable" : "Aktivēt",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Cancel" : "Atcelt",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Close" : "Aizvērt",
    "Group admin for" : "Admin grupa",
    "Quota" : "Apjoms",
    "Language" : "Valoda",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Default quota" : "Apjoms pēc noklusējuma",
    "All languages" : "Visas valodas",
    "Updates" : "Atjauninājumi",
    "Add group" : "Pievienot grupu",
    "Everyone" : "Visi",
    "Admins" : "Admins",
    "Never" : "Nekad",
    "App update" : "Programmu atjaunināšana",
    "SSL Root Certificates" : "SSL Root Sertifikāti",
    "Common Name" : "Kopīgais nosaukums",
    "Valid until" : "Derīgs līdz",
    "Issued By" : "Izsniedza",
    "Valid until %s" : "Derīgs līdz %s",
    "Import root certificate" : "Importēt root sertifikātu",
    "Administrator documentation" : "Administratora dokumentācija",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "None" : "Nav",
    "Login" : "Autorizēties",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-pasta serveris",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "mail" : "e-pasts",
    "Authentication method" : "Autentifikācijas metode",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Test email settings" : "Izmēģināt e-pasta iestatījumus",
    "Send email" : "Sūtīt e-pastu",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Version" : "Versija",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Please read carefully before activating server-side encryption: " : "Lūdzu, izlasiet uzmanīgi pirms aktivējiet servera šifrēšanu:",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Start migration" : "Sākt migrāciju",
    "Execute one task with each page loaded" : "Izpildīt vienu uzdevumu ar katru ielādēto lapu",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Expire after " : "Nederīga pēc",
    "days" : "dienas",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Allow users to share via link" : "Ļaut lietotājiem koplietot caur saitēm",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Personal" : "Personīgs",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "Profile picture" : "Profila attēls",
    "Upload new" : "Ielādēt jaunu",
    "Select from Files" : "Izvēlēties no Datnes",
    "Remove image" : "Novākt attēlu",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Choose as profile picture" : "Izvēlēties kā profila attēlu",
    "Details" : "Detaļas",
    "Full name" : "Pilns vārds",
    "No display name set" : "Nav norādīts ekrāna vārds",
    "Your email address" : "Jūsu e-pasta adrese",
    "No email address set" : "Nav norādīts e-pasts",
    "Phone number" : "Tālruņa numurs",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Address" : "Adrese",
    "Your postal address" : "Jūsu pasta adrese",
    "Website" : "Mājaslapa",
    "Twitter" : "Twitter",
    "Help translate" : "Palīdzi tulkot",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Store credentials" : "Saglabāt akreditācijas datus",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Share" : "Koplietot"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
